@@ -59,7 +59,8 @@ describe 'memcached' do
       :user            => 'nobody',
       :max_connections => '8192',
       :install_dev     => false,
-      :processorcount  => 1
+      :processorcount  => 1,
+      :use_sasl        => false
     }
   end
 
@@ -76,7 +77,8 @@ describe 'memcached' do
       :user            => 'somebdy',
       :max_connections => '8193',
       :verbosity       => 'vvv',
-      :processorcount  => 3
+      :processorcount  => 3,
+      :use_sasl        => true
     },
     {
       :package_ensure  => 'present',
@@ -91,6 +93,10 @@ describe 'memcached' do
       :verbosity       => 'vvv',
       :install_dev     => true,
       :processorcount  => 1
+    },
+    {
+      :package_ensure  => 'absent',
+      :install_dev     => true
     }
   ].each do |param_set|
     describe "when #{param_set == {} ? "using default" : "specifying"} class parameters" do
@@ -133,12 +139,21 @@ describe 'memcached' do
             'group'   => 'root'
           )}
 
-          it { should contain_service("memcached").with(
-            'ensure'     => 'running',
-            'enable'     => true,
-            'hasrestart' => true,
-            'hasstatus'  => false
-          )}
+          it { 
+            if param_hash[:package_ensure] == 'absent'
+              should contain_service("memcached").with(
+                'ensure'     => 'stopped',
+                'enable'     => false
+              )
+            else
+              should contain_service("memcached").with(
+                'ensure'     => 'running',
+                'enable'     => true,
+                'hasrestart' => true,
+                'hasstatus'  => false
+              )
+            end
+          }
 
           it 'should compile the template based on the class parameters' do
             content = param_value(
@@ -171,6 +186,9 @@ describe 'memcached' do
             if(param_hash[:verbosity])
               expected_lines.push("-vvv")
             end
+            if(param_hash[:use_sasl])
+              expected_lines.push("-S")
+            end
             (content.split("\n") & expected_lines).should =~ expected_lines
           end
         end
@@ -185,3 +203,5 @@ describe 'memcached' do
     end
   end
 end
+
+# vim: expandtab shiftwidth=2 softtabstop=2
